/** This file is part of LIDAR Analysis work carried as part of a PhD with Imperial College.  
 * Copyright (c) 2010 Oliver Ford
 *
 * The content, concept and implementation are the intellectual property of Oliver Ford but permission
 * is given for it's use and further development by Jakob Svensson or any person or organisation
 * directly given such permissions by Oliver Ford or by Jakob Svensson.
 */
package seed.minerva.lidar.model;

public interface InsFuncInterface{
	/** @Returns the instrument functions linearly interpolated onto the given temporal grid */
	public double[][] getInsFunc(double dt);
	/** @Returns the ins.Func width in seconds */
	public double[] getFWHMSeconds();	
	/** @Returns the ins.Func width in ADC time units */
	public double[] getApproxFWHMsInADCUs();
	/** @Returns The indices of the peak of the instrument function, 
	 * 				on the given temporal grid */
	public double[] getPeakIdxs(double dt);
	/** @Returns The indices of the centre of mass of the instrument function,
	 * 		 on the given temporal grid */
	public double[] getCentreOfMassIdxs(double dt);
	/** See InstrumentFunctions.cheeseFactors2 */
	public double[] getCheeseFactors2();
	
	/** Get time of peak relative to first element */
	public double[] getPeaks();
	/** Get time of c'o'm relative to first element */
	public double[] getCentresOfMasses();
	
}

