/** This file is part of LIDAR Analysis work carried as part of a PhD with Imperial College.  
 * Copyright (c) 2010 Oliver Ford
 *
 * The content, concept and implementation are the intellectual property of Oliver Ford but permission
 * is given for it's use and further development by Jakob Svensson or any person or organisation
 * directly given such permissions by Oliver Ford or by Jakob Svensson.
 */
package seed.minerva.lidar.util;

import java.io.IOException;

import oneLiners.BinaryMatrixFile;
import oneLiners.OneLiners;

import seed.minerva.lidar.dataProvision.*;

import mds.JetMDSFetcher;
import mds.MDSConnection;
import oneLiners.AsciiMatrixFile;

public class dumpLidrData {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		//args = new String[]{ "/work/lidr/IR/pulseList-dryRuns.txt", "/work/lidr/smfsTest", "/work/data", "127.0.0.1", "8555" };
		boolean offline = false;
		//args = new String[]{ "ke3", "75656", "/work/lidr/ke3", "/work/data-hdf", "mdsplus.jet.efda.org", "8000" };
		//args = new String[]{ "ke9", "68193", "/work/lidr/ke9/preUpgrade/dumpData/", "/work/data-hdf", "mdsplus.jet.efda.org", "8000" };
		args = new String[]{ "ke9", "79503", "/work/lidr/ke9/postUpgrade/dumpData/", "/work/data-hdf", "mdsplus.jet.efda.org", "8000" };
		//args = new String[]{ "ke9", "74614", "/work/lidr/ke9/postUpgrade/dumpData/", "/work/data-hdf", "mdsplus.jet.efda.org", "8000" };
		
		
		if(args.length < 5 || (!args[0].equalsIgnoreCase("ke3") && !args[0].equalsIgnoreCase("ke9"))){
			System.out.println("args: ke3/ke9 pulse/pulseListFile outputdir cacheDir mdsServer mdsPort\n\n");
			return;
		}
		if(args.length > 6)
			offline = "offline".equalsIgnoreCase(args[6]);
		
		int pulses[] = null;
		try{			
			 pulses = new int[]{ Integer.parseInt(args[1]) };
		}catch(NumberFormatException err){
			try{
				double tmp[][] = AsciiMatrixFile.load(args[1], true);
				pulses = new int[tmp[0].length];
				for(int i=0;i<tmp[0].length;i++)
					pulses[i] = (int)tmp[0][i];
			}catch(IOException err2){
				System.err.println("First argument '"+args[1]+"' doesn't seem to be a number or a file that exists.");
				return;
			}
		}
		
		String outputDir = args[2];
		String cacheDir = args[3];
		String mdsServer = args[4];
		int mdsPort = Integer.parseInt(args[5]);
		
		//JetMDSReader jmds = new JetMDSReader(mdsServer,mdsPort,cacheDir);
		JetMDSFetcher jmds = new JetMDSFetcher(mdsServer, mdsPort, cacheDir);
		
		for(int p=0;p<pulses.length;p++){
			System.out.println(pulses[p] + " ("+p+"/"+pulses.length+"):");
			try{
			LidarDataProvider dataProv;
			if(args[0].equalsIgnoreCase("ke3"))
				dataProv = new KE3DataProvider(jmds,pulses[p],~0,0,-1,-1,offline);
			else
				dataProv = new KE9DDataProvider(jmds,pulses[p],~0,0,-1,-1,offline);
					
			
			if(dataProv.frameTimes()!=null)AsciiMatrixFile.mustWrite(outputDir + "/" + pulses[p] + "/frameTimes.txt",new double[][]{ dataProv.frameTimes()}, true);
			if(dataProv.laserEnergies()!=null)AsciiMatrixFile.mustWrite(outputDir + "/" + pulses[p] + "/laserEnergies.txt",new double[][]{ dataProv.laserEnergies()}, true);
			
			if(dataProv.normSpectrums()!=null)
				for(int ch=0;ch<dataProv.nChannels();ch++)
					AsciiMatrixFile.mustWrite(outputDir + "/" + pulses[p] + "/normSpectrum-ch"+ch+".txt", dataProv.normSpectrums()[ch], true);
			
			String miscStr = "nChans\t" + dataProv.nChannels() + "\t1\n" +
					"nFrames\t" + dataProv.nFrames() + "\t1\n" +			
					"signalDt\t" + dataProv.signalDt() + "\ts\n" +
					"ADCUnit\t" + dataProv.ADCUnit() + "\tmv Per ADC Unit\n";
							
			OneLiners.TextToFile(outputDir + "/" + pulses[p] + "/misc.txt", miscStr);
			
			if(dataProv.gains()!=null)
				AsciiMatrixFile.mustWrite(outputDir + "/" + pulses[p] + "/gains.txt", dataProv.gains(), "// mV per (photoelectron per ns)");
			
			if(dataProv.relativeSensitivities()!=null)
				AsciiMatrixFile.mustWrite(outputDir + "/" + pulses[p] + "/relativeSensitivities.txt", dataProv.relativeSensitivities());
			
			if(dataProv.signalFull()!=null)
				for(int f=0;f<dataProv.nFrames();f++)
					BinaryMatrixFile.mustWrite(outputDir + "/" + pulses[p] + "/data-f"+f+".bin",dataProv.signalFrame(f), true);
			if(dataProv.baseLine()!=null)
				BinaryMatrixFile.mustWrite(outputDir + "/" + pulses[p] + "/baseline.bin",dataProv.baseLine(), true);
			
			if(dataProv.vignetting()!=null)
				AsciiMatrixFile.mustWrite(outputDir + "/" + pulses[p] + "/vignetting.txt", dataProv.vignetting(), true);
			//*/
			}catch(RuntimeException err){ err.printStackTrace(); }
		}
	}

}
